{
    "description": "阿里云盘 WebDAV 服务器",
    "home_url": "Module_aliyundrivewebdav.asp",
    "md5": "bca108d2d988601cbb7f067d4630941b",
    "module": "aliyundrivewebdav",
    "title": "阿里云盘WebDAV",
    "version": "0.1.18"
}
